<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Cerrar (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Colapsar</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expadir</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Descartar alerta</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sin título %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo siento</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>No se puede guardar &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Guardar archivo como</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>No se puede sobreescribir &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Renombrar archivo</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>No se puede renombrar &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Todos los cambios se perderán.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Volver a cargar</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Guardar como texto plano descartará cualquier formato, ¿descartar formato?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Archivo alterado</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>¿Desea volver a cargar el archivo?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Volver a cargar</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Archivo eliminado</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>El archivo %1 fue eliminado por otro programa.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>¿Desea guardar o cerrar el archivo?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>No se puede abrir el archivo.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Reemplazar con:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorar mayúsculas</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Solo palabras completas</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Expresiones regulares</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Buscar arriba</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Buscar abajo</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Reemplazar</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Reemplazar &amp;todo</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Replace %n instance?</numerusform>
            <numerusform>Replace %n instances?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo siento</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>No se encontró la frase.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Checar ortografía...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(No se encontraron sugerencias)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imágenes</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie esta aplicación para que los cambios de idioma se realicen.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation type="unfinished">No se puede abrir el archivo.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Chequeo de ortógrafía</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Seleccione diccionario</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo siento</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>No se puede abrir el archivo.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>El archivo no contiene un diccionario utilizable.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Uno o más atajos están en conflicto. ¿Desea continuar?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>El diccionario &quot;%1&quot; ya existe. ¿Desea reemplazarlo?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Meta diaria</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguna</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minutos:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Palabras:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Edición</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Siempre centrar verticalmente</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Cursor de bloque</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Suavizar fuentess</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Sonido de máquina de escribir</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Comillas inteligentes:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dobles</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Sencillas</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Escenas</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Separador:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Recordar la posición del cursor</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Conteo de palabras</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Conteo de páginas</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Conteo de párrafos</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Conteo de caracteres</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caracteres:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Párrafos:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmo de conteo de palabras</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Detectar límite de palabra</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dividir conteo de caracteres por 6</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation>EStilo</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Solo íconos</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Solo texto</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Texto con íconos</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Texto debajo íconos</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posición de texto:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acciones</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Mover arriba</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Mover abajo</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Agregar separador</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Atajo</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Checar ortigrafía mientras escribe</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorar palabras en mayúsculas</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorar palabras con números</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Agregar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Diccionario personal</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Mayus+Abajo</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Mover escenas arriba</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Mayus+Arriba</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Mayus+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Mostrar lista de escenas (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Ocultar lista de escenas (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Mover escenas abajo</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Redimensionar lista de escenas</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Por omisión</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Administrar sesiones</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;esiones</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nueva</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Cambiar a</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nueva sesión</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Renombrar sesión</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>¿Borrar sesión seleccionada?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nombre de sesión:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo siento</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>La sesión solicitada se encuentra en uso.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nueva...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Mayus+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Administrar...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Mayus+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Revertir a predeterminado</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Atajo:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Reemplazando comillas...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Por favor espere</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Checar ortografía</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Agregar</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorar</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnorar todo</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Cambiar</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Ca&amp;mbiar todo</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Fuera del diccionario:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Cambiar a:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Checando ortografía...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Por favor espere</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Chequeo ortográfico completo.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Símbolos usados recientemente</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Todos los símbolos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insertar</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Bloques</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Scripts</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Sin imagen</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrado</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Estirado</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Escalado</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Ajustado</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Margins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Above:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Below:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>pixeles</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Fuente:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Mal escrito:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Linea de espaciado</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simple</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 líneas</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doble</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Propocional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Espaciado de párrafo</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Por omisión</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Old School</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importar tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exportar tema</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>¿Desea eliminar el contador de tiempo?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Palabras:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Páginas:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Párrafos:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caracteres:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Ajustar retraso</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Ajustar tiempo</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Retraso:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tiempo:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarma</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Nota:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>No hay contadores de tiempo en ejecución</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Contador de tiempo</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Reciente</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>¿Desea cancelar contadores de tiempo?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Cargando temas</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Cargando sonidos</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Acerca de FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Un simple procesador de palabras en pantalla completa</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Liberado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Usa íconos del tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Usado bajo la licencia &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caracteres: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Páginas: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Párrafos: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Palabras: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sin título %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Cambiar al siguiente documento</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Cambiar al documento previo</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Cambiar al primer documento</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Cambiar al último documento</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Cambiar al documento %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Cargando preferencias</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>No se puede escribir el caché de emergencia</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter no fue cerrado correctamente</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>¿Restaurar el caché de emergencia?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Algunos archivos no se pueden abrir.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Algunos archivos son de sólo lectura.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; is más reciente que el que se tiene en caché.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>¿Sobreescribir el archivo nuevo?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>No se puede cargar los sonidos de escritura.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Volver a car&amp;gar</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Guardar &amp;como...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Renombrar...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Guardar To&amp;do</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Administrar sesiones</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nueva sesión</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Imprimir...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Pegar &amp;sin formato</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Mayus+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Seleccionar &amp;todo</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Seleccionar e&amp;scena</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Mayus+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmato</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Negrita</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Itálica</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Subrayado</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Ta&amp;chado</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Sup&amp;eríndice</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Subíndice</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Alinear a &amp;Izquierda</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>&amp;Centrar</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Alinear a &amp;Derecha</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Justificar</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Decrementar Indentación</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>A&amp;umentar Indentación</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Bloque &amp;Izquierda a Derecha</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Bloque &amp;Derecha a Izquierda</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Herramientas</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Buscar...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>&amp;Buscar siguiente</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>&amp;Buscar previo</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Reemplazar...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Comillas &amp;inteligentes</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Actualizar &amp;documento</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Actualizar &amp;selección</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Ortografía...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Contador de &amp;tiempo...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;ímbolos...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mostrar &amp;barra de herramientas</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Mostrar &amp;menú de íconos</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Texto enf&amp;ocado</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimizar</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temas...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencias...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Enfoque deshabilitado</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Enfocar una línea</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Enfocar tres líneas</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Párrafo</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Enfocar párrafo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;yuda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de aplicación...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Algunos archivos no está soportados y no podrán ser abiertos.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
